# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import ir_http
from . import res_currency
from . import res_currency_rate
from . import res_lang
from . import spreadsheet_mixin
